summaryrefslogtreecommitdiffstats
path: root/style/src/checkbox.rs
diff options
context:
space:
mode:
Diffstat (limited to 'style/src/checkbox.rs')
-rw-r--r--style/src/checkbox.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/style/src/checkbox.rs b/style/src/checkbox.rs
index 827b3225..52b90ec9 100644
--- a/style/src/checkbox.rs
+++ b/style/src/checkbox.rs
@@ -6,8 +6,8 @@ use iced_core::{Background, Color};
pub struct Appearance {
/// The [`Background`] of the checkbox.
pub background: Background,
- /// The checkmark [`Color`] of the checkbox.
- pub checkmark_color: Color,
+ /// The icon [`Color`] of the checkbox.
+ pub icon_color: Color,
/// The border radius of the checkbox.
pub border_radius: f32,
/// The border width of the checkbox.